*Table 15: Second event: Carillion 

clear all

set maxvar 32767
set matsize 11000

use "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/DealScan2020_merged.dta"

drop year month day deal_qt
keep if dealactivedate_num>=20100101

so packageid facilityid lendercompanyid

*Identify Carillion Lenders with CLO access (Bloomberg)
merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/CarillionLender_CLO2.dta"

gen car_lender=1 if _merge==3
replace car_lender=0 if car_lender==.
drop _merge

gen post=1 if dealactivedate_num>20180101
replace post=0 if post==.

gen lead_arranger=1 if bankallocation==100| agentcredit=="Yes" | leadarrangercredit=="Yes"
replace lead_arranger=0 if lead_arranger==.

*keep only those linked to Compustat
merge m:1 borrowercompanyid facilityid using "/Users/aa21271/Dropbox/Min_Angela_1/JMCB/1st_round/Data/DealScanUpdatedin2020/Dealscan-Compustat Linking Database.dta"
drop if _merge==2
drop _merge

merge m:m borrowercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/JMCB/1st_round/Data/DealScanUpdatedin2020/Dealscan-Compustat Link-wo facilityid.dta", update
drop if _merge==2
drop _merge

*Keep main facilities 
keep if loantype=="Term Loan" | loantype=="Term Loan A" |loantype=="Term Loan B" | loantype=="Revolver/Line < 1 Yr." | loantype=="Revolver/Line >= 1 Yr."

*Borrower industry
gen str4 primarysiccode_temp = string(primarysiccode, "%04.0f")
gen primarysic_1=substr(primarysiccode_temp, 1, 1)
destring primarysic_1, replace 

*Compustat
merge m:1 gvkey deal_yrqt using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/compustat.dta"
drop _merge

*Bank Controls
rename fyearq year
destring year, replace
merge m:1 lendercompanyid year using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/CarillionLenderControls2.dta"
drop if _merge==2
drop _merge

gen ln_maturity=ln(maturity)
gen ln_deal_amount=ln(dealamount+1) 
gen ln_assets = ln(atq)
gen roa= oibdpq/atq
gen coverage= oibdpq/xintq
gen leverage= ltq/atq

*Identify Securitizing Lenders
merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Source Data/SecuritizingLenders.dta"
drop if _merge==2
replace clo_securitizer=1 if _merge==3
replace clo_securitizer=0 if clo_securitizer==.
drop _merge

*Explanatory Variables
gen int_sec_post = clo_securitizer*post
gen int_post_car = post*car_lender
gen int_car_sec = car_lender*clo_securitizer
gen int_sec_post_car = clo_securitizer*post*car_lender

*Labelling
la var lead_arranger "Lead Arranger"
la var post "Post"
la var clo_securitizer "CLO\ Access"
la var car_lender "WC Lender"
la var int_sec_post "CLO\ Access X Post"
la var int_post_car "Post X Carillion"
la var int_car_sec "Carillion X CLO\ Access"
la var int_sec_post_car "CLO\ Access X Post X Carillion"
la var ln_deal_amount "Ln(Deal Amount)"
la var ln_maturity "Ln(Maturity)"
la var int_sec_post_car "CLO\ Access X Post X Carillion"
la var int_sec_post "CLO\ Access X Post"

*Loans with Revolver
merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/revolver_participant"
gen revolver_part=1 if _merge==3
replace revolver_part=0 if revolver_part==.
drop _merge

*Loans with Term Loan A 
merge m:1 lendercompanyid packageid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/packages_with_a"
gen term_a=1 if _merge==3
replace term_a=0 if term_a==.
drop _merge

*Loans with Term Loan B 
merge m:1 lendercompanyid packageid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/packages_with_b"
gen term_b=1 if _merge==3
replace term_b=0 if term_b==.
drop _merge

*Facility Characteristics
merge m:1 facilityid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/n_part_in_fac.dta"
drop if _merge==2
drop _merge

merge m:1 packageid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/LoanSpread_Pac.dta",
drop if _merge==2
drop _merge

merge m:1 facilityid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/allindrawn.dta"
drop if _merge==2
drop _merge

gen log_n_part=log(n_part)
gen log_spread_total=log(loanspread_total)

gen termA_revoler=1 if loantype=="Term Loan A"| loantype=="Revolver/Line < 1 Yr." | loantype=="Revolver/Line >= 1 Yr."
gen revolver=1 if loantype=="Revolver/Line < 1 Yr." | loantype=="Revolver/Line >= 1 Yr." 

replace revolver=0 if revolver==.
gen term_a_1=1 if loantype=="Term Loan A"
replace term_a_1=0 if term_a_1==.
gen term_1=1 if loantype=="Term Loan"
replace term_1=0 if term_1==.
gen term_terma_1=1 if loantype=="Term Loan A" | loantype=="Term Loan"
replace term_terma_1=0 if term_terma_1==.
gen term_b_1=1 if loantype=="Term Loan B"
replace term_b_1=0 if term_b_1==.  
gen st_revolver=1 if loantype=="Revolver/Line < 1 Yr."
replace st_revolver=0 if st_revolver==.
gen lt_revolver=1 if loantype=="Revolver/Line >= 1 Yr."
replace lt_revolver=0 if lt_revolver==.

*Bank Controls from Compustat
merge m:1 gvkey year using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/compustat_annual.dta"
drop if _merge==2
drop _merge

gen log_at=log(at)
gen ln_bank_ta=ln(bank_total_assets)
gen bank_eq_to_ta=bank_total_equity/bank_total_assets
replace bank_roae=bank_roae/100
replace bank_roe=bank_roe/100
gen bank_deposit_to_ta=bank_deposits_customers/bank_total_assets
gen bank_cashcasheq_ta=bank_cashcasheq/bank_total_assets
gen bank_liq_to_assets=bank_liquidassets/bank_total_assets

la var loanspread_total "Total Loan Spread"
la var log_n_part "Ln(N of Loan Participants)"
la var lead_arranger "Prob(Lead Arranger)"
la var ln_bank_ta "Ln(Lender Size)"
la var bank_eq_to_ta "Lender Capital"
la var bank_roae "Lender ROA"
la var bank_deposit_to_ta "Lender Deposit"
la var bank_cashcasheq_ta "Lender Liquidity"

*Bank control construction
egen ln_bankta_pre=mean(ln_bank_ta), by(lendercompanyid post)
replace ln_bankta_pre=. if post==1
bysort lendercompanyid (ln_bankta_pre) : gen ln_bankta_pre2 = ln_bankta_pre[1]
gen int_ln_bankta_pre_post=ln_bankta_pre2*post

egen bank_eq_to_ta_pre=mean(bank_eq_to_ta), by(lendercompanyid post)
replace bank_eq_to_ta_pre=. if post==1
bysort lendercompanyid (bank_eq_to_ta_pre) : gen bank_eq_to_ta_pre2 = bank_eq_to_ta_pre[1]
gen int_bank_eq_to_ta_pre_post=bank_eq_to_ta_pre2*post

egen bank_roae_pre=mean(bank_roae), by(lendercompanyid post)
replace bank_roae_pre=. if post==1
bysort lendercompanyid (bank_roae_pre) : gen bank_roae_pre2 = bank_roae_pre[1]
gen int_bank_roae_pre_post=bank_roae_pre2*post

egen bank_deposit_to_ta_pre=mean(bank_deposit_to_ta), by(lendercompanyid post)
replace bank_deposit_to_ta_pre=. if post==1
bysort lendercompanyid (bank_deposit_to_ta_pre) : gen bank_deposit_to_ta_pre2 = bank_deposit_to_ta_pre[1]
gen int_bank_deposit_to_ta_pre_post=bank_deposit_to_ta_pre2*post

egen bank_cashcasheq_ta_pre=mean(bank_cashcasheq_ta), by(lendercompanyid post)
replace bank_cashcasheq_ta_pre=. if post==1
bysort lendercompanyid (bank_cashcasheq_ta_pre) : gen bank_cashcasheq_ta_pre2 = bank_cashcasheq_ta_pre[1] 
gen int_bank_cashcasheq_ta_pre_post=bank_cashcasheq_ta_pre2*post

la var int_ln_bankta_pre_post "Ln(Lender Size) X Post"
la var int_bank_eq_to_ta_pre_post "Lender Capital X Post"
la var int_bank_roae_pre_post "Lender ROA X Post"
la var int_bank_deposit_to_ta_pre_post "Lender Deposit X Post"
la var int_bank_cashcasheq_ta_pre_post "Lender Liquidity X Post"

egen lender_qt=group(lendercompanyid deal_yrqt)
egen borrower_qt=group(borrowercompanyid deal_yrqt)
egen borrower_lender=group(borrowercompanyid lendercompanyid) 
egen ind_qt=group(primarysic_1 deal_yrqt)

merge m:1 packageid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/pack_with_termb.dta"
drop if _merge==2
drop _merge

save "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/Carillion.dta", replace 

*********************************************************************************************************
*START HERE 
clear all

set maxvar 32767
set matsize 11000

use "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Hypotheses Test/Carillion/Carillion.dta"

*Drop Carillion
drop if borrowercompanyid==33078

*Drop firms in the Carillion's industry group
tostring primarysiccode, replace 
gen sic_1digit= substr(primarysiccode, 1, 1)
gen sic_2digit= substr(primarysiccode, 1, 2)

*Sample period: 2years before and after Carillion's collapse 
keep if dealactivedate_num>=20160101
keep if dealactivedate_num<20200101

*Drop the quarter of Carillion's collapse 
drop if datafqtr=="2018Q1"

*Deal Lead Arranger 
keep if loantype=="Term Loan" | loantype=="Term Loan A" |loantype=="Term Loan B" | loantype=="Revolver/Line < 1 Yr." | loantype=="Revolver/Line >= 1 Yr." 

gen fac_rev=1 if loantype=="Revolver/Line < 1 Yr." | loantype=="Revolver/Line >= 1 Yr." | loantype=="364-Day Facility"
replace fac_rev=0 if fac_rev!=1
gen fac_term_loan=1 if loantype=="Term Loan" 
gen fac_term_a=1 if loantype=="Term Loan A"

replace fac_term_a=0 if fac_term_a!=1
gen fac_term_b=1 if loantype=="Term Loan B"
replace fac_term_b=0 if fac_term_b!=1

so packageid facilityid 
by packageid: egen deal_w_rev=sum(fac_rev)
by packageid: egen deal_w_term_loan=sum(fac_term_loan)

by packageid: egen deal_w_term_a=sum(fac_term_a)
by packageid: egen deal_w_term_b=sum(fac_term_b)

replace deal_w_rev=1 if deal_w_rev>0
replace deal_w_term_loan=1 if deal_w_term_loan>0

replace deal_w_term_a=1 if deal_w_term_a>0
replace deal_w_term_b=1 if deal_w_term_b>0

gen deal_la=1 if lead_arranger==1 & fac_term_a==1 
replace deal_la=1 if lead_arranger==1 & deal_la==. & fac_term_loan==1
replace deal_la=1 if lead_arranger==1 & deal_la==. & fac_rev==1
replace deal_la=1 if lead_arranger==1 & deal_la==. & fac_term_b==1
replace deal_la=0 if deal_la==.
la var deal_la "Prob(Lead Arranger) in Deals"

*Keep deal level info
keep deal_la post clo_securitizer car_lender int_sec_post_car int_sec_post int_post_car int_car_sec lendercompanyid primarysic_1 deal_yrqt packageid deal_w_term_b deal_w_term_a deal_w_term_loan deal_w_rev dealpurpose dealamount maturity ind_qt year dealactivedate_num  
duplicates drop 

*Drop Deals with only revolving facilities
gen rev_only=1 if deal_w_rev==1 & deal_w_term_a==0 & deal_w_term_b==0 & deal_w_term_loan==0
replace rev_only=0 if rev_only==.


*Table 15: Second event: Carillion 
eststo clear
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0, absorb(lendercompanyid primarysic_1 deal_yrqt) vce(cluster packageid lendercompanyid) noconstant
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0, absorb(lendercompanyid ind_qt) vce(cluster packageid lendercompanyid) noconstant
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0 & deal_w_term_b==0, absorb(lendercompanyid primarysic_1 deal_yrqt) vce(cluster packageid lendercompanyid) noconstant
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0 & deal_w_term_b==0, absorb(lendercompanyid ind_qt) vce(cluster packageid lendercompanyid) noconstant
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0 & deal_w_term_b==1, absorb(lendercompanyid primarysic_1 deal_yrqt) vce(cluster packageid lendercompanyid) noconstant
eststo: reghdfe deal_la int_sec_post_car int_sec_post int_post_car if rev_only==0 & deal_w_term_b==1, absorb(lendercompanyid ind_qt) vce(cluster packageid lendercompanyid) noconstant
esttab using tab_deal2.tex, title ("Probability(Lead Arranger) in Syndicated Loan Deals: Triple-Differences") star(* 0.10 ** 0.05 *** 0.01) se(3) b(3) ar2 replace label

