*Figure 3: Deal origination trend by WorldCom Sec vs Non-Sec banks

*Contruct n of deals for lender-month from DealScan
clear all 
use "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Base Data/Pac_Lead_Arranger.dta"

merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/dealscan data work/DealScan in excel/Company - lendercompanyid.dta"
drop if _merge==2
drop _merge
gen bank_dummy = strpos(institutiontype, "Bank") > 0
keep if bank_dummy==1

keep lendercompanyid packageid deal_leadarr dealactivedate dealactivedate_num year
duplicates drop

split dealactivedate, g(part) p("/")
rename part3 deal_startyear
rename part2 deal_startmonth
rename part1 deal_startday
gen dealstartdate_temp = deal_startyear + "-" + deal_startmonth + "-" + deal_startday

gen deal_start_date = date(dealstartdate_temp, "YMD")
format deal_start_date %td
gen deal_start_ym = mofd(deal_start_date)
format deal_start_ym %tm
gen deal_start_yq = qofd(deal_start_date)
format deal_start_yq %tq

so lendercompanyid deal_start_yq
gen count=1
by lendercompanyid deal_start_yq: egen ndeals_by_lenderqtr=sum(count)
drop count

so lendercompanyid deal_start_ym
gen count=1
by lendercompanyid deal_start_ym: egen ndeals_by_lendermonth=sum(count)
drop count

merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Base Data/ALL WC Lender - lendercompanyid only.dta"
gen wc_lender=1 if _merge==3
replace wc_lender=0 if wc_lender==.
drop _merge

drop if dealactivedate_num<20010101
drop if dealactivedate_num>20031231

merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Source Data/SecuritizingLenders.dta"
drop if _merge==2
gen sec_bank=1 if _merge==3
replace sec_bank=0 if _merge==1
drop _merge
save "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Base Data/N_Deals_by_Lender_Quarter_Month_WC_SEC.dta", replace

*
clear all
use "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Base Data/N_Deals_by_Lender_Quarter_Month_WC_SEC.dta", replace

keep if wc_lender==1
so deal_start_ym
collapse ndeals_by_lendermonth, by (deal_start_ym sec_bank)
reshape wide ndeals_by_lendermonth, i(deal_start_ym) j(sec_bank)

gen group=1
gen controlscale_temp= ndeals_by_lendermonth0 if deal_start_ym==tm(2001m1)
gen treatscale_temp= ndeals_by_lendermonth1 if deal_start_ym==tm(2001m1)
so group
by group: egen controlscale=max(controlscale_temp)
by group: egen treatscale=max(treatscale_temp)
drop controlscale_temp treatscale_temp

gen ndeals_by_nonsec_scaled= ndeals_by_lendermonth0*100/controlscale
gen ndeals_by_sec_scaled= ndeals_by_lendermonth1*100/treatscale

la var ndeals_by_nonsec_scaled "NonSec Banks"
la var ndeals_by_sec_scaled "Sec Banks"

sum ndeals_by_sec_scaled ndeals_by_nonsec_scaled
local max=`r(max)'
gen c=`max' if deal_start_ym>m(2002m3)&deal_start_ym<m(2002m8)
lab var c "WorldCom Trouble Months"

drop if deal_start_ym<m(2001m3) | deal_start_ym>m(2003m8)

*Figure 3
twoway (area c deal_start_ym, bcolor(gs15)) (line ndeals_by_nonsec_scaled deal_start_ym, lpattern(dash) lcolor(black)) (line ndeals_by_sec_scaled deal_start_ym, lpattern(solid) lcolor(red)), subtitle("N of Deals Originated by Sec or NonSec Banks") xtitle("Monthly") ytitle("N of Deals") saving(ndeals_by_sec_nonsec)

********************************************************************************************************************************

*Figure 4: Deal origination trends (Term B Deals vs Non-Term B Deals)
clear all
set mat 5000
use "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Preliminary Test/ndeals_by_lender.dta"

merge m:1 lendercompanyid using "/Users/aa21271/Dropbox/Min_Angela_1/Analysis/Base Data/ALL WC Lender.dta"
gen wc_lender=1 if _merge==3
replace wc_lender=0 if wc_lender==.
drop _merge

egen t=group(deal_start_yq)

la var n_deals "Number of Deals"

*Quarterly DiD - sec vs nonsec within WorldCom
keep if wc_lender==1

forvalues t=1(1)10{
gen int`t'=clo_securitizer*(t==`t')
}

local ys n_deals n_deals_with_termB n_deals_without_termB
set more off


foreach y in `ys'{ 
areg `y' int2-int10 i.t, absorb(lendercompanyid) vce(cluster lendercompanyid)
mat b=e(b)
mat v=e(V)
mat beta=(b[1,1..9])'
mat ci_low=(0)
mat ci_high=(0)
forvalues i=1(1)9{
mat ci_low=ci_low\(b[1,`i']-invnormal(0.975)*sqrt(v[`i',`i']))
mat ci_high=ci_high\(b[1,`i']+invnormal(0.975)*sqrt(v[`i',`i']))
}
mat ci_low=ci_low[2..10,1]
mat ci_high=ci_high[2..10,1]
mat t=(0)
mat t=[-4, -3, -2, -1, 0, 1, 2, 3, 4]'
svmat beta
svmat t
svmat ci_low
svmat ci_high
twoway scatter beta t1, color(black) || line beta t1, color(black) || rline ci_high ci_low t1, color(black) lpattern(-) ylabel(#2) subtitle("Pre-trend: securitization banks relative to others") xtitle("Quarterly relative to 2002Q2") ///
ytitle("`y'") legend(label(1 "{&gamma}{sub:t}") label(3 "95% CI")) legend(order(1 3)) xline(0) saving(gr`y'.gph, replace)
clear matrix
drop beta* t1* ci_*
graph combine gr`y'.gph
}

twoway scatteri 1 1, msymbol(i) ylab("") xlab("") ytitle("") xtitle("") yscale(off) xscale(off) plotregion(lpattern(blank)) name(blank, replace)

*Figure 4
graph combine grn_deals.gph blank grn_deals_with_termB.gph grn_deals_without_termB.gph












